@@ -423,7 +423,7 @@ class PhotoExporter:
             return
 
         fileutil = options.fileutil or FileUtil
-        self._temp_dir = fileutil.tmpdir(prefix="osxphotos_export_", dir=options.tmpdir)
+        self._temp_dir = fileutil.tmpdir(prefix="osxphotos_export_", dirpath=options.tmpdir)
         self._temp_dir_path = pathlib.Path(self._temp_dir.name)
         return
 
@@ -1075,7 +1075,7 @@ class PhotoExporter:
                 last_data = photoinfo_minify_dict(json.loads(rec.photoinfo))
                 # to avoid issues with datetime comparisons, list order
                 # need to deserialize from photo.json() instead of using photo.asdict()
-                current_data = json.loads(self.photo.json(shallow=True))
+                current_data = photoinfo_minify_dict(json.loads(self.photo.json(shallow=False)))
                 try:
                     diff = dictdiff(last_data, current_data)
                 except Exception as e:
@@ -1187,7 +1187,7 @@ class PhotoExporter:
 
         # export to a subdirectory of tmpdir
         tmpdir = self.fileutil.tmpdir(
-            "osxphotos_applescript_export_", dir=self._temp_dir_path
+            "osxphotos_applescript_export_", dirpath=self._temp_dir_path
         )
 
         exported_files = []
