@@ -1,4 +1,4 @@
-""" photo_query and QueryOptions class for PhotosDB.query """
+"""photo_query and QueryOptions class for PhotosDB.query"""
 
 from __future__ import annotations
 
@@ -448,7 +448,7 @@ def photo_query(
     name = normalize_unicode(options.name)
 
     if album:
-        photos = _get_photos_by_attribute(photos, "albums", album, options.ignore_case)
+        photos = filter_photos_by_folder_album_path(photos, album, options.ignore_case)
 
     if keyword:
         photos = _get_photos_by_attribute(
@@ -466,19 +466,9 @@ def photo_query(
         photos = _get_photos_by_attribute(photos, "labels", label, options.ignore_case)
 
     if folder:
-        # search for photos in an album in folder
-        # finds photos that have albums whose top level folder matches folder
-        photo_list = []
-        for f in folder:
-            photo_list.extend(
-                [
-                    p
-                    for p in photos
-                    if p.album_info
-                    and f in [a.folder_names[0] for a in p.album_info if a.folder_names]
-                ]
-            )
-        photos = photo_list
+        photos = filter_photos_by_folder_album_path(
+            photos, folder, options.ignore_case, True
+        )
 
     if title:
         # search title field for text
@@ -888,6 +878,101 @@ def photo_query(
     return photos
 
 
+def filter_photos_by_folder_album_path(
+    photos: list[PhotoInfo],
+    paths: list[str],
+    ignore_case: bool = False,
+    folders_only: bool = False,
+) -> list[PhotoInfo]:
+    """Filter photos based on full album/folder paths
+
+    Args:
+        photos: a list of PhotoInfo objects
+        paths: list of paths to search for (e.g. ["Folder/Subfolder/Album1", "Folder2/Album2"])
+        ignore_case: ignore case when searching
+        folders_only: if True, treat paths as folder paths and find photos in any albums within those folders
+
+    Returns:
+        list of PhotoInfo objects matching search criteria
+
+    Notes:
+        - Paths should be in format "Folder/Subfolder/.../Album" (or just "Folder/Subfolder" if folders_only=True)
+        - Forward slashes in folder/album names should be escaped as "//"
+        - Multiple paths are combined with OR logic
+        - If folders_only=True, finds photos in any albums that are children of the specified folder path
+    """
+    if not paths:
+        return photos
+
+    # Normalize paths for comparison
+    normalized_paths = []
+    for path in paths:
+        # Handle escaped forward slashes: replace "//" with a placeholder
+        # then split on "/" and restore the escaped slashes
+        placeholder = "\x00ESCAPED_SLASH\x00"
+        path_normalized = path.replace("//", placeholder)
+        path_parts = [
+            part.replace(placeholder, "/") for part in path_normalized.split("/")
+        ]
+
+        if ignore_case:
+            path_parts = [part.lower() for part in path_parts]
+
+        normalized_paths.append(path_parts)
+
+    matching_photos = []
+
+    for photo in photos:
+        photo_matched = False
+        # Check each album the photo is in
+        for album_info in photo.album_info:
+            # Build the full path for this album
+            # folder_names gives us the hierarchy: ["Top folder", "sub folder", ...]
+            folder_names = album_info.folder_names or []
+            album_title = album_info.title or ""
+
+            if folders_only:
+                # For folders_only mode, we only care about the folder hierarchy
+                # Check if the album's folder path starts with any of our target folder paths
+                if ignore_case:
+                    folder_names_compare = [part.lower() for part in folder_names]
+                else:
+                    folder_names_compare = folder_names
+
+                # Check if this album's folder hierarchy matches any target folder path
+                for target_path_parts in normalized_paths:
+                    # Check if the album's folder hierarchy starts with the target folder path
+                    if (
+                        len(folder_names_compare) >= len(target_path_parts)
+                        and folder_names_compare[: len(target_path_parts)]
+                        == target_path_parts
+                    ):
+                        matching_photos.append(photo)
+                        photo_matched = True
+                        break  # Found a match for this photo
+            else:
+                # Original exact path matching logic
+                # Construct full path: folder_names + album_title
+                full_path_parts = folder_names + [album_title]
+
+                if ignore_case:
+                    full_path_parts_compare = [part.lower() for part in full_path_parts]
+                else:
+                    full_path_parts_compare = full_path_parts
+
+                # Check if this path matches any of our target paths
+                for target_path_parts in normalized_paths:
+                    if full_path_parts_compare == target_path_parts:
+                        matching_photos.append(photo)
+                        photo_matched = True
+                        break  # Found a match for this photo
+
+            if photo_matched:
+                break  # No need to check other albums for this photo
+
+    return list(set(matching_photos))  # Remove duplicates
+
+
 def _get_photos_by_attribute(photos, attribute, values, ignore_case):
     """Search for photos based on values being in PhotoInfo.attribute
 
